@@ -16,7 +16,7 @@ distname = 'astroid'
 
 modname = 'astroid'
 
-version = '1.5.0'
+version = '1.5.2'
 numversion = tuple(map(int, version.split('.')))
 
 extras_require = {}
@@ -35,8 +35,12 @@ def has_environment_marker_range_operators_support():
 
 if has_environment_marker_range_operators_support():
     extras_require[':python_version<"3.4"'] = ['enum34', 'singledispatch']
-elif py_version < (3, 4):
-    install_requires.extend(['enum34', 'singledispatch'])
+    extras_require[':python_version<"3.3"'] = ['backports.functools_lru_cache']
+else:
+    if py_version < (3, 4):
+        install_requires.extend(['enum34', 'singledispatch'])
+    if py_version < (3, 3):
+        install_requires.append('backports.functools_lru_cache')
 
 
 # pylint: disable=redefined-builtin; why license is a builtin anyway?
